@@ -2,14 +2,14 @@
 
 from twisted.internet.defer import Deferred, maybeDeferred
 from twisted.internet.protocol import ReconnectingClientFactory
+from twisted.python.failure import Failure
+
 try:
     from twisted.protocols.amp import (
         Argument, String, Integer, Command, AMP, MAX_VALUE_LENGTH)
 except ImportError:
     from landscape.lib.twisted_amp import (
         Argument, String, Integer, Command, AMP, MAX_VALUE_LENGTH)
-    
-from twisted.python.failure import Failure
 
 from landscape.lib.bpickle import loads, dumps, dumps_table
 
@@ -173,7 +173,7 @@ class MethodCallClientProtocol(AMP):
         deferred = Deferred()
 
         def handle_response(response):
-            if call.called:
+            if not call.active():
                 # Late response for a request that has timeout,
                 # just ignore it.
                 return
