@@ -6,7 +6,7 @@ from landscape.tests.helpers import (LandscapeTest, ManagerHelper,
                                      ProcessDataBuilder)
 from landscape.lib.process import ProcessInformation
 
-from landscape.manager.manager import SUCCEEDED, FAILED
+from landscape.manager.plugin import SUCCEEDED, FAILED
 from landscape.manager.processkiller import (
     ProcessKiller, ProcessNotFoundError, ProcessMismatchError,
     SignalProcessError)
@@ -138,7 +138,6 @@ class ProcessKillerTests(LandscapeTest):
                               "result-text": expected_text}])
         self.assertTrue("ProcessNotFoundError" in self.logfile.getvalue())
 
-
     def test_signal_process_start_time_mismatch(self):
         """
         When a 'signal-process' message is received with a mismatched
