@@ -2,7 +2,7 @@ from twisted.python.failure import Failure
 from twisted.internet.error import ProcessTerminated
 
 from landscape import SERVER_API
-from landscape.manager.manager import SUCCEEDED, FAILED
+from landscape.manager.plugin import SUCCEEDED, FAILED
 from landscape.manager.shutdownmanager import (
     ShutdownManager, ShutdownProcessProtocol)
 from landscape.tests.helpers import (
@@ -50,6 +50,9 @@ class ShutdownManagerTest(LandscapeTest):
         protocol.result.addCallback(restart_performed)
         protocol.childDataReceived(0, "Data may arrive ")
         protocol.childDataReceived(0, "in batches.")
+        # We need to advance both reactors to simulate that fact they
+        # are loosely in sync with each other
+        self.broker_service.reactor.advance(10)
         self.manager.reactor.advance(10)
         return protocol.result
 
@@ -100,6 +103,7 @@ class ShutdownManagerTest(LandscapeTest):
         self.plugin.perform_shutdown(message)
 
         stash = []
+
         def restart_performed(ignore):
             self.assertEquals(stash, [])
             stash.append(True)
