@@ -18,7 +18,7 @@ class UserMonitor(MonitorPlugin):
     """
 
     persist_name = "users"
-    run_interval = 3600 # 1 hour
+    run_interval = 3600  # 1 hour
     name = "usermonitor"
 
     def __init__(self, provider=None):
@@ -30,7 +30,6 @@ class UserMonitor(MonitorPlugin):
     def register(self, registry):
         super(UserMonitor, self).register(registry)
 
-        self.registry.reactor.call_on("resynchronize", self._resynchronize)
         self.call_on_accepted("users", self._run_detect_changes, None)
 
         factory = UserMonitorProtocolFactory(object=self)
@@ -46,8 +45,7 @@ class UserMonitor(MonitorPlugin):
 
     def _resynchronize(self):
         """Resynchronize user and group data."""
-        changes = UserChanges(self._persist, self._provider)
-        changes.clear()
+        super(UserMonitor, self)._resynchronize()
         return self._run_detect_changes()
 
     def run(self, operation_id=None):
