@@ -379,7 +379,7 @@ class TwistedReactor(EventHandlingReactorMixin,
     def stop(self):
         """Stop the reactor, a C{"stop"} event will be fired."""
 
-        self._reactor.crash()
+        self._reactor.stop()
         self._cleanup()
 
     def time(self):
